Learn R Programming

aridagri (version 2.0.3)

anova_strip: ============================================================================ ADDITIONAL EXPERIMENTAL DESIGN FUNCTIONS Package: aridagri Authors: Lalit Kumar Rolaniya, Ram Lal Jat, Monika Punia, Raja Ram Choudhary ============================================================================ Strip Plot Design ANOVA

Description

Performs ANOVA for Strip Plot (Strip-Split) Design where two factors are applied in horizontal and vertical strips.

Usage

anova_strip(
  data,
  response,
  horizontal_factor,
  vertical_factor,
  replication,
  alpha = 0.05,
  verbose = TRUE
)

Value

List containing ANOVA results

Arguments

data

Data frame containing the experimental data

response

Name of the response variable

horizontal_factor

Factor applied in horizontal strips (A)

vertical_factor

Factor applied in vertical strips (B)

replication

Name of replication factor

alpha

Significance level

verbose

Logical. If TRUE (default), prints formatted output to console.

Author

Lalit Kumar Rolaniya, Ram Lal Jat, Monika Punia, Raja Ram Choudhary

Examples

Run this code
data <- expand.grid(
  rep = 1:4,
  irrigation = c("I1", "I2", "I3"),
  tillage = c("CT", "MT", "ZT")
)
data$yield <- rnorm(nrow(data), 1200, 150)
anova_strip(data, response = "yield", horizontal_factor = "irrigation",
            vertical_factor = "tillage", replication = "rep")

Run the code above in your browser using DataLab