Learn R Programming

aridagri (version 2.0.3)

thermal_indices: Growing Degree Days (GDD) and Thermal Indices

Description

Calculates Growing Degree Days, Helio-thermal Units, Photo-thermal Units, and Heat Use Efficiency from temperature data.

Usage

thermal_indices(
  tmax,
  tmin,
  base_temp = 10,
  sunshine_hours = NULL,
  day_length = NULL,
  crop_yield = NULL,
  biomass = NULL,
  verbose = TRUE
)

Value

List with thermal indices

Arguments

tmax

Vector of daily maximum temperatures (C)

tmin

Vector of daily minimum temperatures (C)

base_temp

Base temperature (C)

sunshine_hours

Vector of daily sunshine hours (optional)

day_length

Vector of day length in hours (optional)

crop_yield

Crop yield for HUE calculation (optional)

biomass

Biomass for HUE calculation (optional)

verbose

Logical. If TRUE (default), prints formatted output to console.

Author

Lalit Kumar Rolaniya, Ram Lal Jat, Monika Punia, Raja Ram Choudhary

Examples

Run this code
tmax <- runif(90, 30, 42)
tmin <- runif(90, 18, 28)
thermal_indices(tmax, tmin, base_temp = 10)

Run the code above in your browser using DataLab