The aridagri package provides comprehensive statistical and analytical tools for agricultural research. It includes complete ANOVA functions for all experimental designs, multiple post-hoc tests, stability analysis methods, thermal indices, crop growth analysis, and advanced statistical methods.
anova_crd: Completely Randomized Design
anova_rbd: Randomized Block Design
anova_rbd_pooled: Pooled RBD (Multi-Environment)
anova_latin: Latin Square Design
anova_factorial: Two-Factor Factorial
anova_factorial_3way: Three-Factor Factorial
anova_spd: Split Plot Design
anova_sspd: Split-Split Plot Design
anova_strip: Strip Plot Design
anova_augmented: Augmented Block Design
anova_alpha_lattice: Alpha Lattice Design
perform_posthoc: Multiple comparison tests (LSD, Duncan, Tukey, SNK, Scheffe, Bonferroni, Dunnett)
check_assumptions: ANOVA assumption checking
stability_analysis: Multi-method stability analysis (Eberhart-Russell, AMMI, Finlay-Wilkinson, Shukla, Wricke, CV, Superiority)
thermal_indices: GDD, HTU, PTU, Heat Use Efficiency
crop_growth_analysis: CGR, RGR, NAR, LAI
harvest_index: Harvest index and partitioning
yield_gap_analysis: Yield gap calculations
economic_indices: B:C ratio, net returns
correlation_analysis: Correlation matrix with significance
pca_analysis: Principal component analysis
path_analysis: Path coefficient analysis
sem_analysis: Structural equation modeling
nue_calculate: Nutrient use efficiency calculations
nutrient_response: Response curve analysis
economic_analysis: Economic viability assessment
Lalit Kumar Rolaniya, Ram Lal Jat, Monika Punia, Raja Ram Choudhary
Useful links: